print "# A PRIORY CALIBRATION:"

print "# Measurement set = uid___A002_X24c120_X18c.ms"

print "# Running fixplanets on fields with 0,0 coordinates."


listobs(vis = 'uid___A002_X24c120_X18c.ms',
  listfile = 'uid___A002_X24c120_X18c.ms.listobs')

# Sources:
# J1924-292   --> Pointing
# Titan       --> Amplitude calibrator
# J1517-243   --> Bandpass calibrator
# J1604-446   --> Phase calibrator
# GRB110715A  --> Science source
#
# Time observed ~1 hour total, ~25 min. on science target. 
# 4 spw, TDM mode


print "# Generation of the WVR calibration table."

os.system("wvrgcal --ms uid___A002_X24c120_X18c.ms --output uid___A002_X24c120_X18c.ms.wvr --toffset -1 --segsource")

print "# Checking the solutions of the WVR calibration table." 
 
plotcal(caltable = 'uid___A002_X24c120_X18c.ms.wvr',
 xaxis = 'time',
 yaxis = 'phase',
 spw = '1,3,5,7',
 subplot = 221,
 iteration = 'spw,antenna',
 plotsymbol = ',')

raw_input ("Please press NEXT button in the CASA plotter pop-up window and then press enter to continue the script.")

print "# Generation of the Tsys cal table."

gencal(vis = 'uid___A002_X24c120_X18c.ms',
  caltable = 'uid___A002_X24c120_X18c.ms.tsys',
  caltype = 'tsys')


interTsys=aU.InterpolateTsys('uid___A002_X24c120_X18c.ms.tsys')

interTsys.correctBadTimes()
interTsys.assignFieldAndScanToSolution()

clearstat()


print "# Checking the solutions of the Tsys calibration table." 
plotcal(caltable = 'uid___A002_X24c120_X18c.ms.tsys',
 xaxis = 'freq',
 yaxis = 'amp',
 poln='',
 spw='',
 subplot = 221,
 plotrange = [0,0,60,700],
 iteration = 'antenna,spw',
 plotsymbol = ',')

raw_input ("Please press NEXT button in the CASA plotter pop-up window and then press enter to continue the script.")

#Comments: spw 7 shows strong atmospheric lines
#          DV12 shows a problem in polarization X in spw 7 (I cannot see the athmospheric spectral lines where they should supposed be)
#          Strong diferences in Tsys in the direction of Titan (Titan is at a very low elevation).


print "# A priori flagging."

flagmanager(vis = 'uid___A002_X24c120_X18c.ms',
 mode = 'save',
 versionname = 'Original_flagged')


flagdata(vis = 'uid___A002_X24c120_X18c.ms',
  mode = 'manualflag',
  autocorr = T,
  flagbackup = F)


flagdata(vis = 'uid___A002_X24c120_X18c.ms',
  mode = 'manualflag',
  intent = '*POINTING*,*ATMOSPHERE*',
  flagbackup = F)

flagdata(vis = 'uid___A002_X24c120_X18c.ms',
 mode = 'shadow',
 flagbackup = F)


print "# Application of the WVR and Tsys cal tables."

for i in ['1', '2']:  
  applycal(vis = 'uid___A002_X24c120_X18c.ms',
    spw = '1,3,5,7',
    field = i,
    gaintable = ['uid___A002_X24c120_X18c.ms.tsys','uid___A002_X24c120_X18c.ms.wvr'],
    gainfield = [i, ''],
    flagbackup = F)

applycal(vis = 'uid___A002_X24c120_X18c.ms',
  spw = '1,3,5,7',
  field = '3,4',
  gaintable = ['uid___A002_X24c120_X18c.ms.tsys','uid___A002_X24c120_X18c.ms.wvr'],
  gainfield = ['3', ''],
  flagbackup = F)


print "# Splitting the data."

split(vis = 'uid___A002_X24c120_X18c.ms',
  outputvis = 'uid___A002_X24c120_X18c.ms.split',
  datacolumn = 'corrected',
  spw = '1,3,5,7',
  keepflags = F)


